@@ -44,10 +44,9 @@ inline double prho(std::vector<double> x,
     // compute variances and covariance
     double v_x = 0.0, v_y = 0.0, cov = 0.0, wi_sq;
     for (size_t i = 0; i < n; i++) {
-        wi_sq = weights[i] * weights[i];
-        v_x += x[i] * x[i] * wi_sq;
-        v_y += y[i] * y[i] * wi_sq;
-        cov += x[i] * y[i] * wi_sq;
+        v_x += x[i] * x[i] * weights[i];
+        v_y += y[i] * y[i] * weights[i];
+        cov += x[i] * y[i] * weights[i];
     }
 
     // compute correlation
